==> domframework_0.58.orig.tar.bz2: domframework-0.58/Tests/macaddressesTest.php <==
<?php
/** DomFramework - Tests
  * @package domframework
  * @author Dominique Fournier <dominique@fournier38.fr>
  */

/** Test the macaddresses.php file */
class test_macaddresses extends PHPUnit_Framework_TestCase
{
  public function test_isMACAddress_1 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("");
    $this->assertSame (false, $res);
  }

  public function test_isMACAddress_2 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("INVALID");
    $this->assertSame (false, $res);
  }

  public function test_isMACAddress_3 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("de:ad:be:af:aa:bb");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_4 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("de-ad-be-af-aa-bb");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_5 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("0005.313B.9080");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_6 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("0005313B9080");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_7 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("a0005313B9080a");
    $this->assertSame (false, $res);
  }

  public function test_addSeparator_1 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080");
    $this->assertSame ("00:05:31:3B:90:80", $res);
  }

  public function test_addSeparator_2 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080", "-");
    $this->assertSame ("00-05-31-3B-90-80", $res);
  }

  public function test_addSeparator_3 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080", ".", 4);
    $this->assertSame ("0005.313B.9080", $res);
  }

  public function test_addSeparator_4 ()
  {
    $this->expectException ();
    $res = macaddresses::addSeparator ("INVALID", ".", 4);
  }

  public function test_removeSeparator_1 ()
  {
    $res = macaddresses::removeSeparator("de:ad:be:af:aa:bb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_2 ()
  {
    $res = macaddresses::removeSeparator("de-ad-be-af-aa-bb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_3 ()
  {
    $res = macaddresses::removeSeparator("dead.beaf.aabb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_4 ()
  {
    $res = macaddresses::removeSeparator("deadbeafaabb");
    $this->assertSame ("deadbeafaabb", $res);
  }
}

==> domframework_0.60.orig.tar.bz2: domframework-0.60/Tests/macaddressesTest.php <==
<?php
/** DomFramework - Tests
  * @package domframework
  * @author Dominique Fournier <dominique@fournier38.fr>
  */

/** Test the macaddresses.php file */
class macaddressesTest extends PHPUnit_Framework_TestCase
{
  public function test_isMACAddress_1 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("");
    $this->assertSame (false, $res);
  }

  public function test_isMACAddress_2 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("INVALID");
    $this->assertSame (false, $res);
  }

  public function test_isMACAddress_3 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("de:ad:be:af:aa:bb");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_4 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("de-ad-be-af-aa-bb");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_5 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("0005.313B.9080");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_6 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("0005313B9080");
    $this->assertSame (true, $res);
  }

  public function test_isMACAddress_7 ()
  {
    $macaddresses = new macaddresses ();
    $res = $macaddresses->isMACAddress ("a0005313B9080a");
    $this->assertSame (false, $res);
  }

  public function test_addSeparator_1 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080");
    $this->assertSame ("00:05:31:3B:90:80", $res);
  }

  public function test_addSeparator_2 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080", "-");
    $this->assertSame ("00-05-31-3B-90-80", $res);
  }

  public function test_addSeparator_3 ()
  {
    $res = macaddresses::addSeparator ("0005313B9080", ".", 4);
    $this->assertSame ("0005.313B.9080", $res);
  }

  public function test_addSeparator_4 ()
  {
    $this->expectException ();
    $res = macaddresses::addSeparator ("INVALID", ".", 4);
  }

  public function test_removeSeparator_1 ()
  {
    $res = macaddresses::removeSeparator("de:ad:be:af:aa:bb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_2 ()
  {
    $res = macaddresses::removeSeparator("de-ad-be-af-aa-bb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_3 ()
  {
    $res = macaddresses::removeSeparator("dead.beaf.aabb");
    $this->assertSame ("deadbeafaabb", $res);
  }

  public function test_removeSeparator_4 ()
  {
    $res = macaddresses::removeSeparator("deadbeafaabb");
    $this->assertSame ("deadbeafaabb", $res);
  }
}
